# eocanvas

EOCanvas provides a Python 3.8+ client to interact with the WEkEO Serverless Functions service API.

The documentation about the service can be found at https://wekeo.eu.

The documentation for this package can be found at: https://eocanvas.readthedocs.io/en/latest/

## Contribution

Contribute to the development of this client by creating an account on GitHub. You can follow this guidelines for a general overview of the needed steps: https://github.com/firstcontributions/first-contributions.

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update this README as appropriate - changes on the interface, version etc.

## Licence
Please refer to LICENSE.txt
